exceptiontools.UndefinedSpacingError
====================================

.. inheritance-diagram:: abjad.tools.exceptiontools.UndefinedSpacingError.UndefinedSpacingError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.UndefinedSpacingError.UndefinedSpacingError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.UndefinedSpacingError.UndefinedSpacingError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.UndefinedSpacingError.UndefinedSpacingError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.UndefinedSpacingError.UndefinedSpacingError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.UndefinedSpacingError.UndefinedSpacingError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.UndefinedSpacingError.UndefinedSpacingError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.UndefinedSpacingError.UndefinedSpacingError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.UndefinedSpacingError.UndefinedSpacingError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.UndefinedSpacingError.UndefinedSpacingError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
